#
# spec file for package python-Flask-Cors
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Flask-Cors
Version:        5.0.0
Release:        1.3
Summary:        A Flask extension adding a decorator for CORS support
License:        MIT
URL:            https://github.com/corydolphin/flask-cors
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Cors/flask_cors-%{version}.tar.gz
BuildRequires:  %{python_module Flask >= 0.9}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 0.9
BuildArch:      noarch
%python_subpackages

%description
A Flask extension for handling Cross Origin Resource Sharing (CORS),
making cross-origin AJAX possible.

%prep
%setup -q -n flask_cors-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%{python_sitelib}/flask_cors
%{python_sitelib}/Flask_Cors-%{version}*-info

%changelog
* Wed Sep 25 2024 Caroline Sena <caroline.sena@suse.com>
- version update to 5.0.0:
  * Breaking: Change default to disable private network access by
    @corydolphin in #368. This effectively resolves
    GHSA-hxwh-jpp2-84pm https://osv.dev/vulnerability/PYSEC-2024-71
* Tue Aug 13 2024 Guang Yee <gyee@suse.com>
- version update to 4.0.1
  * Address CVE-2024-1681 which is a log injection vulnerability
    when the log level is set to debug by @aneshujevic in :issue:`351`
* Mon Oct  2 2023 pgajdos@suse.com
- version update to 4.0.0
  * Remove support for Python versions older than 3.8 by @WAKayser in #330
  * Add GHA tooling by @corydolphin in #331
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Jan  6 2022 Ben Greiner <code@bnavigator.de>
- Six is required unconditionally
* Wed Nov  3 2021 Steve Kowalik <steven.kowalik@suse.com>
- Use pytest to run the testsuite.
* Sun Apr  4 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.0.10:
  * Adds support for PPC64 and ARM64 builds for distribution. Thanks
    @sreekanth370
* Tue Sep  1 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.0.9:
  * Escape path before evaluating resource rules. Prior to this,
    flask-cors incorrectly evaluated CORS resource matching before
    path expansion. E.g. "/api/../foo.txt" would incorrectly match
    resources for "/api/*" whereas the path actually expands
    simply to "/foo.txt" (CVE-2020-25032, boo#1175986)
- Remove patch which is no longer required when using (at least)
  Flask 1.1, which is the case in Factory:
  * 0001-Disable-ACL_ORIGIN-check.patch
* Tue Oct 22 2019 Petr Cervinka <petr@cervinka.net>
- Add patch 0001-Disable-ACL_ORIGIN-check.patch to disable failing
  ACL_ORIGIN check in test (boo#1154808)
* Sat Jun  8 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.0.8:
  * DeprecationWarning: Using or importing the ABCs from 'collections'
    instead of from 'collections.abc' is deprecated, and in 3.8 it
    will stop working
* Mon Nov 12 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 3.0.7:
  * Updated logging.warn to logging.warning (#234) Thanks Vaibhav
* Tue Jul 17 2018 alarrosa@suse.com
- Require python-six in Leap 42.3 to fix build
* Mon Jul 16 2018 tchvatal@suse.com
- Enable testsuite
* Thu Jul 12 2018 alarrosa@suse.com
- Initial package for python-Flask-Cors 3.0.6
